#include "ChangeThemeCommand.h"
#include "Themes.h"
#include <States/ChangeStateCommand.h>

void ChangeThemeCommand::execute() {
    Themes::Instance().change_theme();

    const auto width = config::GAME_VIDEO_MODE.width;
    const auto height = config::GAME_VIDEO_MODE.height;
    const auto room_color = Themes::Instance().get_game_color_room();

    auto easy_level_command = std::make_unique<GameCommand>(
        m_menu.m_state_manager,
        std::make_unique<GameBuilderDirector>(
            std::make_unique<SimpleBuilder>(width, height, config::ROOM_SIZE, room_color, 0),
            config::GAME_VIDEO_MODE,
            config::EASY_GAME_TITLE,
            config::EASY_GAME_ENEMY_RATIO));

    auto medium_level_command = std::make_unique<GameCommand>(
        m_menu.m_state_manager,
        std::make_unique<GameBuilderDirector>(
            std::make_unique<SimpleBuilder>(width, height, config::ROOM_SIZE, room_color, config::ENEMY_SPEED_MEDIEUM),
            config::GAME_VIDEO_MODE,
            config::MEDIUM_GAME_TITLE,
            config::MEDIUM_GAME_ENEMY_RATIO));

    auto hard_level_command = std::make_unique<GameCommand>(
        m_menu.m_state_manager,
        std::make_unique<GameBuilderDirector>(
            std::make_unique<ComplexBuilder>(width, height, config::ROOM_SIZE, room_color, config::ENEMY_SPEED_HARD),
            config::GAME_VIDEO_MODE,
            config::HARD_GAME_TITLE,
            config::HARD_GAME_ENEMY_RATIO));

    auto extreme_level_command = std::make_unique<GameCommand>(
        m_menu.m_state_manager,
        std::make_unique<GameBuilderDirector>(
            std::make_unique<ComplexRandomBuilder>(width, height, config::ROOM_SIZE, room_color, config::ENEMY_SPEED_EXTREME),
            config::GAME_VIDEO_MODE,
            config::EXTREME_GAME_TITLE,
            config::HARD_GAME_ENEMY_RATIO));

    auto change_theme_command = std::make_unique<ChangeThemeCommand>(m_menu);

    m_menu.m_buttons[0].change_text_color();
    m_menu.m_buttons[0].change_button_color();
    m_menu.m_buttons[0].change_command(std::move(easy_level_command));

    m_menu.m_buttons[1].change_text_color();
    m_menu.m_buttons[1].change_button_color();
    m_menu.m_buttons[1].change_command(std::move(medium_level_command));

    m_menu.m_buttons[2].change_text_color();
    m_menu.m_buttons[2].change_button_color();
    m_menu.m_buttons[2].change_command(std::move(hard_level_command));

    m_menu.m_buttons[3].change_text_color();
    m_menu.m_buttons[3].change_button_color();
    m_menu.m_buttons[3].change_command(std::move(extreme_level_command));

    m_menu.m_buttons[4].change_text_color();
    m_menu.m_buttons[4].change_button_color();
    m_menu.m_buttons[4].change_command(std::make_unique<ExitCommand>(m_menu.m_state_manager));

    m_menu.m_buttons[5].change_text_color();
    m_menu.m_buttons[5].change_button_color();
    m_menu.m_buttons[5].change_button_text(Themes::Instance().get_button_change_theme_text());
    m_menu.m_buttons[5].change_command(std::move(change_theme_command));
}